#' Summarized length-at-age data by species and season for all species in Wisconsin.
#'
#' Summarized length-at-age data by species and season for all species in Wisconsin.
#'
#' @name GrowthSum14
#'
#' @docType data
#' 
#' @format A data frame with 995 observations on the following 10 variables.
#'\describe{
#'  \item{commonName}{A string that contains the species' common name.}
#'  \item{season}{A string that contains a code for season (\code{1_JanMay}, \code{2_JunJul}, \code{3_AugSep}, \code{4_OctDec}, and \code{ALL})}
#'  \item{speciesCode}{A string that contains the species' name code.}
#'  \item{age}{A numeric for age.}
#'  \item{meanLen}{A numeric of mean length-at-age (inches).}
#'  \item{sdLen}{A numeric of sd length-at-age (inches).}
#'  \item{minLen}{A numeric of minimum length-at-age (inches).}
#'  \item{maxLen}{A numeric of maximum length-at-age (inches).}
#'  \item{numFish}{Number of fish represented in the results.}
#'  \item{numMeans}{Number of survey means used to construct the results.}
#'}
#'
#' @note The workbook contains mean length at age summaries compiled from all available electronic sources of data including the current FH Database (includes Treaty), the Front End Statewide Data Entry System, and the Historic Paradox Database (see detailed breakdown below) for lakes and flowages in Wisconsin.  The \dQuote{statewide} averages presented here are not a representative sample from all regions of the state (e.g., does not include data from SE, and very little from WCR).  However, the summaries do cover the state from the extreme North to the extreme South (see below).   Age determination and age verification were done by managers and technicians, and values reported in the various databases were assumed to be accurate (no additional verification was done).
#' 
#' \dQuote{Statewide} mean length at age was calculated for each species from survey sample means (i.e., not from individual fish).   So, for a given waterbody surveyed in a particular year and season, the average length at age was calculated from the individual fish lengths and ages.  Then the resulting survey mean lengths at age were used to generate the statewide average.  Thus, each survey was given the same weight in the statewide average.   The mean lengths at age reported are straight averages, and not mean lengths at age extrapolated from a growth curve , which will be the next step.
#' 
#' There were few records available in the historic and current databases where it was clear that lengths were back-calculated lengths.   Therefore, it was assumed that the majority of the lengths were not back-calculated as the Fish Management Handbook suggests (see Section 11-2 below).  Records that were clearly identified as having back-calculated lengths were not included in these summaries.  Mean length at age summaries were then generated separately by season.   Mean lengths at age for the January - May season would be comparable to the values reported in the Fish Management Reference Book.   Unfortunately, the computer files from the Fish Management Reference Book are no longer available.  We will continue to refine these summaries in this workbook as more information becomes available.
#' 
#' Excerpt from the Fish Management Handbook, Section 11-2 -- \dQuote{The length at age should be reported at time of annulus formation, therefore all aging done during the growing season should have lengths back-calculated to time of annulus formation.   Aging structures collected from all species between October 1st and May 1st in Southern Wisconsin and between September 1st and June 1st in Northern Wisconsin can be used without back-calculations.   Length at age data collected before the fall cutoff dates will be reported to the previous springs annuli.  Length at age collected after the fall cutoff date and before the spring sampling will have the last annulus counted.}
#' 
#' @author Prepared by Nancy Nate (8-Nov-2003) and revised by Tim Simonson (20-Feb-14).
#' 
#' @keywords datasets
#' 
#' @examples
#' data(GrowthSum14)
#' 
#' if (require(dplyr)) {
#'   ( bg <- filter(GrowthSum14,commonName=="BLUEGILL",season=="ALL") )
#'   ( lmb <- filter(GrowthSum14,commonName=="LARGEMOUTH BASS",season=="1_JanMay"))
#' 
#' }
NULL
